A dictionary of Dynamic values with string keys.
Not available under no_object.
SmartString is used as the key type because most
property names are ASCII and short, fewer than 23 characters, so they can be stored inline.
A dictionary of Dynamic values with string keys.
Not available under no_object.
SmartString is used as the key type because most
property names are ASCII and short, fewer than 23 characters, so they can be stored inline.